pub struct Diagonal2 {
pub xx: f64,
pub yy: f64,
}Expand description
A diagonal matrix, suitable for representing anisotropic scaling.
Fields
xx: f64The horizontal expansion factor.
yy: f64The vertical expansion factor.
Implementations
Sourceimpl Diagonal2
impl Diagonal2
Sourcepub const fn inv(self) -> Self
pub const fn inv(self) -> Self
Matrix inverse.
Will of course produce infinities if a component is zero.
Sourcepub fn scale_normal(self, n: Vec2) -> Vec2
pub fn scale_normal(self, n: Vec2) -> Vec2
Scale a normal vector.
This is mathematically equivalent to self * (self * n).normalize()
for positive transforms, but handles zeros and gets the sign correct
when negative.
Note that n need not be unit length.