pub fn expand_path_signed(
path: impl Shape,
expand: Diagonal2,
join: Join,
miter_limit: f64,
tolerance: f64,
) -> BezPathExpand description
Expand a path when the sign is known.
Applies the expansion based on the path orientation, so that expansion happens
with positive expand values on subpaths with negative area, or vice versa. This
is backwards from the intuitive sign convention, but results from the choice of
convention for the offset primitives.